@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] BASEテンプレートの読み込みを変更
  -      [2007/07/05] 絵文字コンバートで文字コードの変更はなし
  -      [2007/02/13] 公開レベルを保持
  -      [2006/09/20] $this->base['uri_separator']を追加
@@ -94,6 +95,8 @@ class WAP_friend extends RKT_webapp
         $this->account = $objact->getInfo();
         $this->base['account'] = $this->account;
 
+        $this->setTemplateBase('base/friend.tpl');
+
         $this->__initialize();
 
         /* PathInfo引数の設定 */
