@@ -81,14 +81,12 @@ class webapp extends WAP_friend
                     'LEFT JOIN '.DB_PREFIX.'com_picture pic '.
                     'ON com.id = pic.ref_community AND '.
                        'pic.status = '.STATUS_PICTURE_COMMUNITY.','.
-                DB_PREFIX.'com_category cat,'.
                 DB_PREFIX.'com_names nms '.
             'WHERE '.
                 'com.id = nms.ref_community AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
                 sql_query::bitFlag('nms.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
-                'nms.ref_account = '.$this->ref_friend.' AND '.
-                'cat.id = com.ref_category '.
+                'nms.ref_account = '.$this->ref_friend.' '.
             'ORDER BY '.
                 'nms.modify ';
         $objpgr->setSql($sql);
