@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] メールによる画像添付機能追加
  -      [2007/07/24] 過去の日付指定を追加
  -      [2007/07/24] カテゴリ選択更新時エラーを修正
  -      [2007/06/16] 日記の公開レベルを追加
@@ -73,6 +74,12 @@ class webapp extends WAP_private
      */
     var $dia_select = array();
 
+    /**
+     * 添付画像を送信
+     * @var integer
+     */
+    var $attach = 0;
+
     /**
      * 実行処理
      *
@@ -103,8 +110,9 @@ class webapp extends WAP_private
         }
         $this->set_ref_diary();
 
-        // 選択済みカテゴリの取得
-        $this->set_dia_select();
+        
+        $this->set_dia_select();        // 選択済みカテゴリの取得
+        $this->set_attach();            // 画像添付フラグの設定
 
         // データ操作クラスの生成
         $this->objmnp = new RKT_manip($this->objdb,  DB_PREFIX.'dia_entry');
@@ -115,11 +123,15 @@ class webapp extends WAP_private
             // 選択済みカテゴリ処理
             $this->do_query_select();
             unset($_SESSION['dia_select']);
+            
+            $this->mail_action();
+            unset($_SESSION['attach']);
 
-            header('Location: '.HTTP_ACTION.'private/diary/entry/'.$this->sid.'/'.WAP_URI_SEPARATOR.'id='.$this->id);
+            header('Location: '.HTTP_ACTION.'private/diary/post/'.$this->sid.'/complete/'.WAP_URI_SEPARATOR.'id='.$this->id.'&attach='.$this->attach);
             exit();
         } elseif($result == RKT_MANIP_VALIDATED) {
             $_SESSION['dia_select'] = $this->dia_select;
+            $_SESSION['attach']     = $this->attach;
             header('Location: '.HTTP_ACTION.'private/diary/post/'.$this->sid.'/confirm/'.WAP_URI_SEPARATOR.'id='.$this->id);
             exit();
         }
@@ -138,6 +150,7 @@ class webapp extends WAP_private
             VISIBILITY_HIDDEN=>    VISIBILITY_LABEL_HIDDEN,
         );
         $this->Assign('visibilitys', $visibilitys);
+        $this->Assign('attach', $this->attach);
     }
 
     /**
@@ -588,5 +601,56 @@ class webapp extends WAP_private
                 'ref_entry ='.$ref_entry;
         return $this->objdb->exec($sql);
     }
+
+    /******************************************************/
+    /**************    メールアクション     ***************/
+    /******************************************************/
+    /**
+     * 画像添付フラグの設定
+     *
+     * @access private
+     * @return array
+     */
+    function set_attach()
+    {
+        if (isSet($_POST['attach'])){
+            $this->attach = empty($_POST['attach'])?array():$_POST['attach'];
+            return ;
+        }
+        if (isSet($_SESSION['attach'])){
+            $this->attach = empty($_SESSION['attach'])?array():$_SESSION['attach'];
+            return ;
+        }
+        if (isSet($_GET['attach'])){
+            $this->attach = empty($_GET['attach'])?array():$_GET['attach'];
+            return ;
+        }
+        if (preg_match('/(manip|confirm|edit)/i',$_SERVER['REQUEST_URI'])){
+            return ;
+        }
+    }
+
+    /**
+     * メールアクション設定
+     *
+     * @access private
+     * @return integer  データ操作結果
+     */
+    function mail_action()
+    {
+        if (empty($this->attach)){
+            return false;
+        }
+        $ref_relation = $this->objmnp->getCurID();
+
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_mailaction');
+
+        $objmnp->setValue('modify',        date('Y-m-d H:i:s'));
+        $objmnp->setValue('ref_table',     ACTION_DIA_ENTRY);
+        $objmnp->setValue('ref_relation',  $ref_relation);
+        $objmnp->setValue('ref_account',   $this->account['id']);
+
+        return $objmnp->manip();
+    }
 } // webapp
 ?>
