@@ -93,16 +93,14 @@ class webapp extends WAP_private
             'WHERE '.
                 'avail = '.AVAIL_ENABLE.' AND '.
                 'status = '.STATUS_FRIEND_CONNECT.' AND '.
-                'ref_account = '.$this->account['id'] .' '.
+                'ref_account = '.$this->account['id'] .' AND '.
                 'id = '.$this->id;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
-        $ref_friend = ($result['ref_account'] != $this->account['id'])
-                            ?$result['ref_account']:$result['ref_friend'];
-        $friend = $this->get_friend($result['id'],$ref_friend);
+        $friend = $this->get_friend($result['id'], $result['ref_friend']);
         
         $this->Assign('friend', $friend);
     }
