@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/20] XSS対応
  -      [2007/01/31] 通常ファイル添付に対応
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -104,7 +105,9 @@ class community_pictures
         if (!empty($_POST['picture_delete'])){
             $deletes = array();
             foreach ($_POST['picture_delete'] as $id) {
-                $deletes[$id] = $id;
+                if (is_numeric($id)){
+                    $deletes[$id] = $id;
+                }
             }
             $_SESSION['picture_delete'] = $deletes;
         } // if (!empty($_POST['picture_delete']))
@@ -167,7 +170,7 @@ class community_pictures
         $row = 0;
         foreach ($_POST['ref_pictures'] as $id) {
             if (!empty($id)){
-                $this->ids[$id] = $id;
+                $this->ids[$id] = is_numeric($id)?$id:0;
             }
             $this->upload($id, 'photo'.$row);
             $row++;
