@@ -21,12 +21,14 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/11] コミュニティメンバー数の集計を追加
  -      [2007/02/03] お友達招待削除を追加
  -      [2006/08/20] 作成
  - ======================================================================== */
 
 require_once LIB_DIR.'rkt_db.php';
 require_once LIB_DIR.'rkt_blob.php';
+require_once WEBAPP_LIB_DIR.'sql_query.php';
 
 /**
  * 退会、関連レコード削除処理クラス
@@ -512,12 +514,7 @@ class act_exit
     function delete_community()
     {
         /* 名簿の削除 */
-        $sql =
-            'DELETE FROM '.
-                DB_PREFIX.'com_names '.
-            'WHERE '.
-                'ref_account = '.$this->ref_account;
-        $this->objdb->exec($sql);
+        $this->delete_names();
 
         /* コメントの削除 */
         $sql =
@@ -558,6 +555,76 @@ class act_exit
                 'ref_account = '.$this->ref_account;
         $this->objdb->exec($sql);
     }
+
+    /**
+     * コミュニティ名簿の削除
+     *
+     * @access private
+     * @return void
+     */
+    function delete_names()
+    {
+        /* 名簿からコミュニティIDを取得 */
+        $sql=
+            'SELECT '.
+                'ref_community '.
+            'FROM '.
+                DB_PREFIX.'com_names '.
+            'WHERE '.
+                'ref_account = '.$this->ref_account;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+
+        /* 名簿の削除 */
+        $sql =
+            'DELETE FROM '.
+                DB_PREFIX.'com_names '.
+            'WHERE '.
+                'ref_account = '.$this->ref_account;
+        $this->objdb->exec($sql);
+
+        /* コミュニティ会員総数を更新 */
+        foreach ($result as $value){
+            $this->community_total($value['ref_community']);
+        }
+    }
+
+    /**
+     * コミュニティ会員総数を更新
+     *
+     * @access private
+     * @param integer $ref_community
+     * @return void
+     */
+    function community_total($ref_community)
+    {
+        $sql = 
+            'SELECT '.
+                'count(id) as total '.
+            'FROM '.
+                DB_PREFIX.'com_names '.
+            'WHERE '.
+                'ref_community = '.$ref_community. ' AND '.
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO::FETCH_ASSOC);
+        $stmt->closeCursor();
+        $total = empty($result['total'])?0:$result['total'];
+
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'com_community '.
+            'SET '.
+                'total = '.$total.' '.
+            'WHERE '.
+                'id = '.$ref_community;
+        $this->objdb->exec($sql);
+    }
 }
 // act_exitの終了
 ?>
