@@ -462,12 +462,18 @@ class webapp extends WAP_private
      */
     function set_post()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(com.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'ent.id as ref_entry,'.
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
-                'com.modify as modify,'.
+                'max(com.modify) as modify,'.
                 'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
@@ -486,11 +492,13 @@ class webapp extends WAP_private
                 'com.ref_account = '.$this->account['id'].' AND '.
                 'com.modify > '.$this->term.' '.
             'GROUP BY '.
+                'ent.id,'.
                 'act.id,'.
-                'dia.id,'.
-                'ent.id '.
+                'pro.nickname,'.
+                'ent.post,'.
+                'ent.subject '.
             'ORDER BY '.
-                'com.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -507,19 +515,23 @@ class webapp extends WAP_private
      */
     function set_topic()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(tpc.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'com.id as ref_community,'.
                 'com.community as community,'.
                 'tpc.id as ref_topic,'.
                 'tpc.topic as topic,'.
-                'tpc.modify as modify,'.
+                'max(tpc.modify) as modify,'.
                 'tpc.status as status,'.
                 'tpc.post as ct '.
             'FROM '.
-                DB_PREFIX.'com_topic tpc '.
-                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
-                    'ON tpc.id = cmt.ref_topic,'.
+                DB_PREFIX.'com_topic tpc,'.
                 DB_PREFIX.'act_account act,'.
                 DB_PREFIX.'com_community com,'.
                 DB_PREFIX.'com_names nam '.
@@ -535,10 +547,13 @@ class webapp extends WAP_private
                 'nam.status != '.STATUS_COMMUNITY_REQUEST.' '.
             'GROUP BY '.
                 'com.id,'.
+                'com.community,'.
                 'tpc.id,'.
-                'nam.id '.
+                'tpc.topic,'.
+                'tpc.status,'.
+                'tpc.post '.
             'ORDER BY '.
-                'tpc.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -676,12 +691,18 @@ class webapp extends WAP_private
      */
     function set_comment()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(com.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'ent.id as ref_entry,'.
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
-                'com.modify as modify,'.
+                'max(com.modify) as modify,'.
                 'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
@@ -700,10 +721,13 @@ class webapp extends WAP_private
                 'dia.ref_account = '.$this->account['id'].' '.
             'GROUP BY '.
                 'act.id,'.
+                'pro.nickname,'.
                 'dia.id,'.
-                'ent.id '.
+                'ent.id,'.
+                'ent.post,'.
+                'ent.subject '.
             'ORDER BY '.
-                'com.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
