@@ -81,6 +81,7 @@ class webapp extends WAP_private
                 'pro.modify as modify,'.
                 'pro.first_name as first_name,'.
                 'pro.second_name as second_name,'.
+                'pro.name_flag as name_flag,'.
                 'pro.nickname as nickname,'.
                 'pro.visibility as visibility,'.
                 'pro.prefecture_flag as prefecture_flag,'.
@@ -95,6 +96,7 @@ class webapp extends WAP_private
                 'prf.prefecture as prefecture,'.
                 'lcl.local as local,'.
                 'sex.sex as sex,'.
+                'pro.sex_flag as sex_flag,'.
                 'bld.blood as blood,'.
                 'mrd.married as married,'.
                 'htn.prefecture as hometown,'.
