@@ -67,6 +67,8 @@ class webapp extends WAP_public
         $objauth = new RKT_auth($session_id);
         if (!$objauth->logIn()){
             $url = HTTP_ACTION.'public/login/entrance/'.WAP_URI_SEPARATOR.'mismatch=1&email='.urlencode($_REQUEST['logname']);
+            header('Location: '.$url);
+            exit();
         }
         $status = $objauth->account->getStatus();
         $url = empty($_REQUEST['url'])? $jumps[$status]:$_REQUEST['url'];
