@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] メールアクション設定を追加
  -      [2007/08/05] 画像取得順のNoticeを削除
  -      [2007/07/01] 絵文字用ウインドウデザインの追加
  -      [2006/09/30] コメントの誤字を修正
@@ -258,6 +259,11 @@ class webapp
                 'option'=>   null,
                 'required'=> true,
             ),
+            'action_mail'=> array(
+                'type'=>     'string',
+                'option'=>   null,
+                'required'=> false,
+            ),
             'pop3_host'=> array(
                 'type'=>     'string',
                 'option'=>   null,
@@ -978,6 +984,13 @@ $webapp->execute();
 				</div>
 
 				<div class="formrow"><strong>インポート用メール設定</strong></div>
+				<div class="formrow">
+					<label class="column">インポート用メール：</label>
+					<div class="fdata">{if $alert.action_mail}<span class="alert">入力してください。</span><br />{/if}
+						<input type="text" name="action_mail" value="{$value.action_mail|default:$smarty.const.ACTION_MAIL}" size="60" /><br />
+						携帯ページで画像投稿用に使われます。<br />
+					</div>
+				</div>
 				<div class="formrow">
 					<label class="column">POP3ホスト：</label>
 					<div>
