@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/13] 会員メールアクション追加
 --	[2007/08/05] レビューの対象商品の必須項目を緩和
 --      [2007/07/05] 日記設定：sns_dia_diary.visibilityを削除
 --      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
@@ -241,6 +242,20 @@ CREATE TABLE `sns_act_mobilelogin` (
   UNIQUE (`agent_type`, `loginkey`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- 会員メールアクション
+-- 
+CREATE TABLE `sns_act_mailaction` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_table` int(11) NOT NULL,
+  `ref_relation` int(11) NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `ref_community` int(11),
+  PRIMARY KEY  (`id`),
+  UNIQUE (`ref_table`, `ref_relation`, `ref_account`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
 -- 
 -- 会員退会情報
 -- 
