@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/13] 会員メールアクション追加
 --	[2007/08/05] レビューの対象商品の必須項目を緩和
 --	[2007/08/05] 項目名にダブルクォートを追加
 --      [2007/07/05] 日記設定：sns_dia_diary.visibilityを削除
@@ -255,6 +256,21 @@ CREATE TABLE sns_act_mobilelogin (
   UNIQUE (agent_type, loginkey)
 );
 
+-- 
+-- 会員メールアクション
+-- 
+CREATE SEQUENCE seq_sns_act_mailaction start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_act_mailaction (
+  "id" integer DEFAULT nextval('seq_sns_act_mailaction'::text) NOT NULL,
+  "modify" timestamp without time zone NOT NULL,
+  "ref_table" integer NOT NULL,
+  "ref_relation" integer NOT NULL,
+  "ref_account" integer NOT NULL,
+  "ref_community" integer,
+  PRIMARY KEY  (id),
+  UNIQUE (ref_table, ref_relation, ref_account)
+);
+
 -- 
 -- 会員退会情報
 -- 
