@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/13] 会員メールアクション追加
 --	[2007/08/05] レビューの対象商品の必須項目を緩和
 --      [2007/07/05] 日記設定：sns_dia_diary.visibilityを削除
 --      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
@@ -225,6 +226,20 @@ CREATE TABLE 'sns_act_mobilelogin' (
   UNIQUE ('agent_type', 'loginkey')
 );
 
+-- 
+-- 会員メールアクション
+-- 
+CREATE TABLE 'sns_act_mailaction' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'ref_table' integer NOT NULL,
+  'ref_relation' integer NOT NULL,
+  'ref_account' integer NOT NULL,
+  'ref_community' integer,
+  PRIMARY KEY  ('id'),
+  UNIQUE ('ref_table', 'ref_relation', 'ref_account')
+);
+
 -- 
 -- 会員退会情報
 -- 
